Compute a render state to control subsequent render calls culling mode, blending mode, Z mask, etc... The same render state can be used by different render calls.

See [DrawLines], [DrawTriangles] and [DrawModel].